Properties Methods Events Direct Link

# Class Ext.ux.grid.CheckColumn

Package: | Ext.ux.grid
Defined In: | ux-all-debug.js
Class: | CheckColumn
Extends: | Object

A Column subclass which renders a checkbox in each column cell which toggles the truthiness of the associated data field on click.

Note. As of ExtJS 3.3 this no longer has to be configured as a plugin of the GridPanel.

Example usage:

    var cm = new Ext.grid.ColumnModel([{
           header: 'Foo',
           ...
        },{
           xtype: 'checkcolumn',
           header: 'Indoor?',
           dataIndex: 'indoor',
           width: 55
        }
    ]);

    // create the grid
    var grid = new Ext.grid.EditorGridPanel({
        ...
        colModel: cm,
        ...
    });

In addition to toggling a Boolean value within the record data, this class toggles a css class between `'x-grid3-check-col'` and `'x-grid3-check-col-on'` to alter the background image used for a column.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.